%define anolis_release 3
%bcond_with tests

# This bcond allows to ship a non-compiled version
# Slower, but sometimes necessary with alpha Python versions
%bcond_without cython_compile

Name:           Cython
Version:        0.29.32
Release:        %{anolis_release}%{?dist}
Summary:        Language for writing Python extension modules

License:        ASL 2.0
URL:            http://www.cython.org
Source:         https://github.com/cython/cython/archive/%{version}/Cython-%{version}.tar.gz

# Wrap the docstring of cython-default-compile-format to 80 characters
# Upstream PR: https://github.com/cython/emacs-cython-mode/pull/1
# Fixes https://bugzilla.redhat.com/2155090
Patch:          emacs-docstring-wrap.patch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%if %{with tests}
BuildRequires:  gcc-c++
BuildRequires:  python3-numpy
BuildRequires:  python3-jedi
%endif

%if %{with cython_compile}
BuildRequires:  gcc
%global python3_site %{python3_sitearch}
%else
BuildArch:      noarch
%global python3_site %{python3_sitelib}
%endif

%global _description %{expand:
The Cython language makes writing C extensions for the Python language as easy
as Python itself. Cython is a source code translator based on Pyrex,
but supports more cutting edge functionality and optimizations.

The Cython language is a superset of the Python language (almost all Python
code is also valid Cython code), but Cython additionally supports optional
static typing to natively call C functions, operate with C++ classes and
declare fast C types on variables and class attributes.
This allows the compiler to generate very efficient C code from Cython code.

This makes Cython the ideal language for writing glue code for external C/C++
libraries, and for fast C modules that speed up the execution of Python code.}

%description %{_description}


%package -n python3-Cython
Summary:        %{summary}
Provides:       Cython = %{version}-%{release}
Provides:       cython = %{version}-%{release}
%py_provides    python3-cython

# A small templating library is bundled in Cython/Tempita
# Upstream version 0.5.2 is available from https://pypi.org/project/Tempita
# but the bundled copy is patched and reorganized.
# Upstream homepage is inaccessible.
Provides:       bundled(python3dist(tempita))

%description -n python3-Cython %{_description}


%package -n emacs-cython-mode
Summary:        A major mode for editing Cython source files in Emacs
BuildArch:      noarch
BuildRequires:  emacs
%{?_emacs_version:
Requires:       emacs(bin) >= %{_emacs_version}
}

%description -n emacs-cython-mode
cython-mode is an Emacs major mode for editing Cython source files.

%package -n python3-Cython-doc
Summary:        %{summary}
BuildArch:      noarch
Requires:	python3-Cython = %{version}-%{release}

%description -n python3-Cython-doc %{_description}
This package contains documentation for %{name}.

%prep
%autosetup -n cython-%{version} -p1


%build
%py3_build -- %{!?with_cython_compile:--no-cython-compile}

# emacs-cython-mode build
echo ";;
(require 'cython-mode)" > cython-mode-init.el
cp -p Tools/cython-mode.el .
%{_emacs_bytecompile} *.el


%install
%py3_install -- %{!?with_cython_compile:--no-cython-compile}

# emacs-cython-mode install
mkdir -p %{buildroot}%{_emacs_sitelispdir}/
cp -p cython-mode.el cython-mode.elc %{buildroot}%{_emacs_sitelispdir}/
mkdir -p %{buildroot}%{_emacs_sitestartdir}/
cp -p cython-mode-init.el cython-mode-init.elc %{buildroot}%{_emacs_sitestartdir}/


%if %{with tests}
%check
%{python3} runtests.py -vv --no-pyregr %{?_smp_mflags}
%endif


%files -n python3-Cython
%license LICENSE.txt
%{_bindir}/cython
%{_bindir}/cygdb
%{_bindir}/cythonize
%{python3_site}/Cython-*.egg-info/
%{python3_site}/Cython/
%{python3_site}/pyximport/
%pycached %{python3_site}/cython.py

%files -n emacs-cython-mode
%license LICENSE.txt
%{_emacs_sitelispdir}/cython*.el*
%{_emacs_sitestartdir}/cython*.el*

%files -n python3-Cython-doc
%doc *.txt Demos Doc Tools

%changelog
* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 0.29.32-3
- Rebuild with python3.11

* Mon Mar 27 2023 happy_orange <songnannan@linux.alibaba.com> - 0.29.32-2
- add doc packages and disable check

* Fri Jan 27 2023 Funda Wang <fundawang@yeah.net> - 0.29.32-1
- Import package for anolis 23
